@@ -11,6 +11,7 @@
 import os
 import platform
 import subprocess
+
 from glob import glob
 
 import nox
@@ -33,6 +34,8 @@ REQUIREMENTS_LINT = ['yapf==0.27', 'pyflakes==2.4.0', 'pytest==6.2.5', 'liccheck
 REQUIREMENTS_TEST = [
     "pytest==6.2.5",
     "pytest-cov==3.0.0",
+    'pytest-xdist==2.5.0',
+    'backoff==2.1.2',
 ]
 REQUIREMENTS_BUILD = ['setuptools>=20.2']
 REQUIREMENTS_BUNDLE = [
@@ -69,13 +72,14 @@ def install_myself(session, extras=None):
     if extras:
         arg += '[%s]' % ','.join(extras)
 
+    session.install('-e', arg)
+
     if INSTALL_SDK_FROM:
         cwd = os.getcwd()
         os.chdir(INSTALL_SDK_FROM)
         session.run('pip', 'uninstall', 'b2sdk', '-y')
         session.run('python', 'setup.py', 'develop')
         os.chdir(cwd)
-    session.install('-e', arg)
 
 
 @nox.session(name='format', python=PYTHON_DEFAULT_VERSION)
@@ -133,8 +137,15 @@ def unit(session):
     install_myself(session)
     session.install(*REQUIREMENTS_TEST)
     session.run(
-        'pytest', '--cov=b2', '--cov-branch', '--cov-report=xml', '--doctest-modules',
-        *session.posargs, 'test/unit'
+        'pytest',
+        '-n',
+        'auto',
+        '--cov=b2',
+        '--cov-branch',
+        '--cov-report=xml',
+        '--doctest-modules',
+        *session.posargs,
+        'test/unit',
     )
     if not session.posargs:
         session.notify('cover')
@@ -145,7 +156,8 @@ def integration(session):
     """Run integration tests."""
     install_myself(session)
     session.install(*REQUIREMENTS_TEST)
-    session.run('pytest', '-s', *session.posargs, 'test/integration')
+    #session.run('pytest', '-s', '-x', '-v', '-n', '4', *session.posargs, 'test/integration')
+    session.run('pytest', '-s', '-x', '-v', *session.posargs, 'test/integration')
 
 
 @nox.session(python=PYTHON_VERSIONS)
@@ -159,6 +171,14 @@ def test(session):
         session.notify('integration')
 
 
+@nox.session(python=PYTHON_DEFAULT_VERSION)
+def cleanup_buckets(session):
+    """Remove buckets from previous test runs."""
+    install_myself(session)
+    session.install(*REQUIREMENTS_TEST)
+    session.run('pytest', '-s', '-x', *session.posargs, 'test/integration/cleanup_buckets.py')
+
+
 @nox.session
 def cover(session):
     """Perform coverage analysis."""
