@@ -50,6 +50,12 @@ class BaseConsoleToolTest(TestBase):
         )
         self.raw_api = self.b2_api.session.raw_api
         (self.account_id, self.master_key) = self.raw_api.create_account()
+        for env_var_name in [
+            B2_APPLICATION_KEY_ID_ENV_VAR,
+            B2_APPLICATION_KEY_ENV_VAR,
+            B2_ENVIRONMENT_ENV_VAR,
+        ]:
+            os.environ.pop(env_var_name, None)
 
     def _get_stdouterr(self):
         stdout = StringIO()
@@ -2201,6 +2207,29 @@ class TestConsoleTool(BaseConsoleToolTest):
         console_tool = ConsoleTool(self.b2_api, stdout, stderr)
         console_tool.run_command(['b2', 'authorize-account', self.account_id, self.master_key])
 
+    def test_passing_api_parameters(self):
+        for command in [
+            [
+                'b2', 'download-file-by-name', '--profile', 'nonexistent', 'dummy-name',
+                'dummy-file-name', 'dummy-local-file-name'
+            ],
+            [
+                'b2', 'download-file-by-id', '--profile', 'nonexistent', 'dummy-id',
+                'dummy-local-file-name'
+            ],
+            ['b2', 'sync', '--profile', 'nonexistent', 'b2:dummy-source', 'dummy-destination'],
+        ]:
+            console_tool = ConsoleTool(
+                None,  # do not initialize b2 api to allow passing in additional parameters
+                mock.MagicMock(),
+                mock.MagicMock(),
+            )
+            console_tool.run_command(
+                command + ['--write-buffer-size', '123', '--skip-hash-verification']
+            )
+            assert console_tool.api.services.download_manager.write_buffer_size == 123
+            assert console_tool.api.services.download_manager.check_hash is False
+
 
 @mock.patch.dict(REALM_URLS, {'production': 'http://production.example.com'})
 class TestConsoleToolWithV1(BaseConsoleToolTest):
